Range-v3: range/v3/algorithm/is_partitioned.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Variables
is_partitioned.hpp File Reference

## Classes
struct | ranges::v3::is_partitioned_fn

## Typedefs
template<typename I , typename C , typename P = ident>
using | ranges::v3::IsPartitionedable = meta::strict_and< InputIterator< I >, IndirectPredicate< C, projected< I, P > >>

## Variables
constexpr with_braced_init_args< is_partitioned_fn > | ranges::v3::is_partitioned {}